@@ -1,4 +1,4 @@
-#' 
+
 #' @title Extract elements from vcfR objects
 #' 
 #'  
@@ -14,8 +14,10 @@
 #' @param verbose should verbose output be generated
 #' @param as.numeric logical, should the matrix be converted to numerics
 #' @param return.alleles logical indicating whether to return the genotypes (0/1) or alleles (A/T)
-#' @param allele.sep character which delimits the alleles in a genotype (/ or |), here this is not used for a regex (as it is in other functions)
+#' @param IDtoRowNames logical specifying whether to use the ID column from the FIX region as rownames
+# @param allele.sep character which delimits the alleles in a genotype (/ or |), here this is not used for a regex (as it is in other functions)
 #' @param extract logical indicating whether to return the extracted element or the remaining string
+#' @param convertNA logical indicating whether to convert "." to NA.
 #' 
 #' @details
 #' 
@@ -26,26 +28,34 @@
 #' The 'as.numeric' option will convert the results from a character to a numeric.
 #' Note that if the data is not actually numeric, it will result in a numeric result which may not be interpretable.
 #' The 'return.alleles' option allows the default behavior of numerically encoded genotypes (e.g., 0/1) to be converted to their nucleic acid representation (e.g., A/T).
-#' The allele.sep parameter allows the genotype delimiter to be specified.
+# The allele.sep parameter allows the genotype delimiter to be specified.
 #' Note that this is not used for a regular expression as similar parameters are used in other functions.
 #' Extract allows the user to extract just the specified element (TRUE) or every element except the one specified.
 #' 
 #' Note that when 'as.numeric' is set to 'TRUE' but the data are not actually numeric, unexpected results will likely occur.
+#' For example, the genotype field will typically be populated with values such as "0/1" or "1|0".
+#' Although these may appear numeric, they contain a delimiter (the forward slash or the pipe) that is non-numeric.
+#' This means that there is no straight forward conversion to a numeric and unexpected values should be expected.
 #' 
 #' 
 #' @seealso
 #' \code{\link{is.polymorphic}}
 #' 
-# @export
 #' 
-# @rdname extract_gt
-#' 
-
-
-
+#' @examples 
+#' data(vcfR_test)
+#' gt <- extract.gt(vcfR_test)
+#' gt <- extract.gt(vcfR_test, return.alleles = TRUE)
 #' 
 #' @export
-extract.gt <- function(x, element="GT", mask=FALSE, as.numeric=FALSE, return.alleles=FALSE, allele.sep="/", extract = TRUE ){
+extract.gt <- function(x, element="GT", 
+                       mask=FALSE,
+                       as.numeric=FALSE, 
+                       return.alleles=FALSE,
+                       IDtoRowNames = TRUE,
+#                       allele.sep="/",
+                       extract = TRUE,
+                       convertNA = TRUE ){
 
   # Validate that we have an expected data structure
   if( class(x) != "chromR" & class(x) != "vcfR" ){
@@ -74,7 +84,7 @@ extract.gt <- function(x, element="GT", mask=FALSE, as.numeric=FALSE, return.all
     mask <- TRUE
   }
   
-  # Validat that the gt slot is a matrix
+  # Validate that the gt slot is a matrix
   if( class(x@gt) != "matrix" ){
     stop( paste("gt slot expected to be of class matrix. Instead found class", class(x@gt)) )
   }
@@ -90,14 +100,30 @@ extract.gt <- function(x, element="GT", mask=FALSE, as.numeric=FALSE, return.all
     }
 #    .Call('vcfR_extract_haps', PACKAGE = 'vcfR', ref, alt, gt, gt_split, verbose)
 #    outM <- .Call('vcfR_extract_GT_to_CM', PACKAGE = 'vcfR', x@gt, element)
-    outM <- .Call('vcfR_extract_GT_to_CM2', PACKAGE = 'vcfR', x@fix, x@gt, element, allele.sep, return.alleles, as.integer(extract) )
-    
+    outM <- .Call('vcfR_extract_GT_to_CM2', PACKAGE = 'vcfR',
+                  x@fix,
+                  x@gt,
+                  element,
+                  return.alleles, 
+                  as.integer(extract), 
+                  convertNA = as.numeric(convertNA) )
   }
 
   # If as.numeric is true, convert to a numeric matrix.
   if(as.numeric == TRUE){
     outM <- .Call('vcfR_CM_to_NM', PACKAGE = 'vcfR', outM)
   }
+  
+  # 
+  if( IDtoRowNames == TRUE ){
+    if( sum(is.na(x@fix[,'ID'])) > 0 ){
+      x <- addID(x)
+    }
+    if( length(unique(x@fix[,'ID'])) != nrow(x@fix) ){
+      stop('ID column contains non-unique names')
+    }
+    rownames(outM) <- x@fix[,'ID']
+  }
 
   # Apply mask.
   if(mask == TRUE){
@@ -111,16 +137,30 @@ extract.gt <- function(x, element="GT", mask=FALSE, as.numeric=FALSE, return.all
 
 #' @rdname extract_gt
 #' @aliases extract.haps
-#' @param gt.split character which delimits alleles in genotypes
+# @param gt.split character which delimits alleles in genotypes
+#' @param unphased_as_NA logical specifying how to handle unphased genotypes
 #' 
 #' @details 
 #' The function \strong{extract.haps} uses extract.gt to isolate genotypes.
 #' It then uses the information in the REF and ALT columns as well as an allele delimiter (gt_split) to split genotypes into their allelic state.
 #' Ploidy is determined by the first non-NA genotype in the first sample.
 #' 
+#' The VCF specification allows for genotypes to be delimited with a '|' when they are phased and a '/' when unphased.
+#' This becomes important when dividing a genotype into two haplotypes.
+#' When the alleels are phased this is straight forward.
+#' When the alleles are unphased it presents a decision.
+#' The default is to handle unphased data by converting them to NAs.
+#' When unphased_as_NA is set to TRUE the alleles will be returned in the order they appear in the genotype.
+#' This does not assign each allele to it's correct chromosome.
+#' It becomes the user's responsibility to make informed decisions at this point.
+#' 
 #' 
 #' @export
-extract.haps <- function(x, mask=FALSE, gt.split="|",verbose=TRUE){
+#extract.haps <- function(x, mask=FALSE, gt.split="|",verbose=TRUE){
+extract.haps <- function(x, 
+                         mask=FALSE, 
+                         unphased_as_NA = TRUE, 
+                         verbose=TRUE ){
   if(class(x) == "chromR"){
     if(length(mask) == 1 && mask==TRUE){
       x <- chromR2vcfR(x, use.mask = TRUE)
@@ -135,10 +175,9 @@ extract.haps <- function(x, mask=FALSE, gt.split="|",verbose=TRUE){
   }
 
   # Determine ploidy  
-#  first.gt <- gt[!is.na(gt)][1]
   first.gt <- unlist(strsplit(x@gt[,-1][!is.na(x@gt[,-1])][1], ":"))[1]
-  ploidy <- length(unlist(strsplit(first.gt, split = gt.split, fixed = TRUE )))
-#  gt <- extract.gt(x, element="GT", return.alleles = TRUE)
+#  ploidy <- length(unlist(strsplit(first.gt, split = gt.split, fixed = TRUE )))
+  ploidy <- length(unlist(strsplit(first.gt, split = "[\\|/]" )))
 
 
   if( nrow( x@fix ) == 0 ){
@@ -148,9 +187,12 @@ extract.haps <- function(x, mask=FALSE, gt.split="|",verbose=TRUE){
     haps <- extract.gt( x )
   } else if ( ploidy > 1 ) {
     gt <- extract.gt( x )
+#    haps <- .Call('vcfR_extract_haps', PACKAGE = 'vcfR', 
+#                  x@fix[,'REF'], x@fix[,'ALT'], 
+#                  gt, gt.split, as.numeric(verbose))
     haps <- .Call('vcfR_extract_haps', PACKAGE = 'vcfR', 
-                  x@fix[,'REF'], x@fix[,'ALT'], 
-                  gt, gt.split, as.numeric(verbose))
+                  x@fix[,'REF'], x@fix[,'ALT'],
+                  gt, as.numeric(unphased_as_NA), as.numeric(verbose))
   } else {
     stop('Oops, we should never arrive here!')
   }
@@ -172,7 +214,21 @@ extract.haps <- function(x, mask=FALSE, gt.split="|",verbose=TRUE){
 #' The function queries the 'REF' and 'ALT' columns of the 'fix' slot to see if any alleles are greater than one character in length.
 #' When the parameter return_indels is FALSE only SNPs will be returned.
 #' When the parameter return_indels is TRUE only indels will be returned.
-#'
+#' 
+#' 
+#' @examples
+#' data(vcfR_test)
+#' getFIX(vcfR_test)
+#' vcf <- extract.indels(vcfR_test)
+#' getFIX(vcf)
+#' vcf@fix[4,'ALT'] <- ".,A"
+#' vcf <- extract.indels(vcf)
+#' getFIX(vcf)
+#' 
+#' data(vcfR_test)
+#' extract.haps(vcfR_test, unphased_as_NA = FALSE)
+#' extract.haps(vcfR_test)
+#' 
 #' 
 #' @export
 extract.indels <- function(x, return.indels=FALSE){
@@ -185,9 +241,12 @@ extract.indels <- function(x, return.indels=FALSE){
 
   # Check reference for indels
   mask <- nchar(x@fix[,'REF']) > 1
+  mask[ grep(".", x@fix[,'REF'], fixed = TRUE) ] <- TRUE
   
   # Check alternate for indels
-  mask[unlist(lapply(strsplit(x@fix[,'ALT'], split=","), function(x){max(nchar(x))})) > 1] <- TRUE
+  mask[unlist(
+    lapply(strsplit(x@fix[,'ALT'], split=","), function(x){ max(nchar(x)) > 1 | length(grep(".",x,fixed=TRUE))>0 })
+    ) ] <- TRUE
 
   if(return.indels == FALSE){
     x <- x[ !mask, , drop = FALSE ]
