@@ -1,5 +1,6 @@
 
-#library(testthat)
+#
+library(testthat)
 library(vcfR)
 context("vcfR2DNAbin functions")
 
@@ -38,6 +39,18 @@ test_that("Works with no variants, ref.seq is not NULL",{
 })
 
 
+test_that("Works with one variant, ref.seq is not NULL",{
+  vcf <- vcf[1,]
+  my_DNAbin <- vcfR2DNAbin( vcf, ref.seq = gene, start.pos = gff[1,4], verbose = FALSE )
+  expect_true( inherits(my_DNAbin, "DNAbin") )
+  expect_equal( dim(my_DNAbin)[1], (ncol(vcf@gt) - 1) * 2 )
+  expect_equal( dim(my_DNAbin)[2], length(gene) )
+  expect_equal( length(ape::seg.sites(my_DNAbin)), 0 )
+  expect_equal( sum(ape::base.freq(my_DNAbin) > 0), 4 )
+})
+
+
+
 
 ##### ##### ##### ##### #####
 #
@@ -49,7 +62,9 @@ data(vcfR_example)
 
 # Fabricate a vcf of haploid data.
 #haps <- extract.haps(vcf)
-haps <- extract.gt(vcf, return.alleles=FALSE, allele.sep="|")
+haps <- extract.gt(vcf, return.alleles=FALSE
+#                   , allele.sep="|"
+                   )
 haps <- apply(haps, MARGIN=2, function(x){unlist(lapply(strsplit(x, split="|"), function(x){x[1]}))})
 gt2 <- extract.gt(vcf, extract = FALSE)
 gt2 <- matrix( paste( haps, gt2, sep=":"), nrow=nrow(haps), dimnames=dimnames(haps) )
@@ -63,7 +78,9 @@ rm(gt2)
 
 # Fabricate a vcf of triploid data.
 #haps <- extract.haps(vcf)
-haps <- extract.gt(vcf, return.alleles=FALSE, allele.sep="|")
+haps <- extract.gt(vcf, return.alleles=FALSE
+#                   , allele.sep="|"
+                   )
 haps2 <- apply(haps, MARGIN=2, function(x){unlist(lapply(strsplit(x, split="|"), function(x){x[1]}))})
 haps <- matrix( paste( haps, haps2, sep="|"), nrow=nrow(haps), dimnames=dimnames(haps) )
 is.na(haps[is.na(haps2)]) <- TRUE
@@ -84,7 +101,8 @@ rm(gt2)
 ##### ##### ##### ##### #####
 
 test_that("vcfR2DNAbin works for haploid data, no ref.seq",{
-  my_DNAbin <- vcfR2DNAbin( vcf1, gt.split = "|" )
+#  my_DNAbin <- vcfR2DNAbin( vcf1, gt.split = "|" )
+  my_DNAbin <- vcfR2DNAbin( vcf1 )
   expect_equal( dim(my_DNAbin)[2], nrow( extract.indels(vcf)@gt ) )
 })
 
@@ -99,7 +117,8 @@ test_that("vcfR2DNAbin works for haploid data, no ref.seq",{
 
 
 test_that("vcfR2DNAbin works for diploid data, no ref.seq",{
-  my_DNAbin <- vcfR2DNAbin( vcf, gt.split = "|", verbose = FALSE )
+#  my_DNAbin <- vcfR2DNAbin( vcf, gt.split = "|", verbose = FALSE )
+  my_DNAbin <- vcfR2DNAbin( vcf, verbose = FALSE )
   expect_true( inherits(my_DNAbin, "DNAbin") )  
   expect_equal( dim(my_DNAbin)[2], nrow( extract.indels(vcf)@gt ) )
   expect_equal( dim(my_DNAbin)[1], 2 * (ncol(vcf@gt) - 1) )
@@ -113,7 +132,8 @@ test_that("vcfR2DNAbin works for diploid data, no ref.seq, wrong gt.split",{
 })
 
 test_that("vcfR2DNAbin with consensus works",{
-  my_DNAbin <- vcfR2DNAbin( vcf, consensus = TRUE, extract.haps = FALSE, gt.split = "|" )
+#  my_DNAbin <- vcfR2DNAbin( vcf, consensus = TRUE, extract.haps = FALSE, gt.split = "|" )
+  my_DNAbin <- vcfR2DNAbin( vcf, consensus = TRUE, extract.haps = FALSE )
   expect_true( inherits(my_DNAbin, "DNAbin") )
   expect_equal( dim(my_DNAbin)[1], ncol(vcf@gt) - 1 )
   expect_equal( dim(my_DNAbin)[2], nrow(extract.indels(vcf)@gt) )
@@ -121,7 +141,8 @@ test_that("vcfR2DNAbin with consensus works",{
 
 
 test_that("vcfR2DNAbin works for diploid data, ref.seq is not NULL",{
-  my_DNAbin <- vcfR2DNAbin( vcf, gt.split = "|", ref.seq = gene, start.pos = gff[1,4], verbose = FALSE )
+#  my_DNAbin <- vcfR2DNAbin( vcf, gt.split = "|", ref.seq = gene, start.pos = gff[1,4], verbose = FALSE )
+  my_DNAbin <- vcfR2DNAbin( vcf, ref.seq = gene, start.pos = gff[1,4], verbose = FALSE )
   expect_true( inherits(my_DNAbin, "DNAbin") )
   expect_equal( dim(my_DNAbin)[1], 2 * (ncol(vcf@gt) - 1) )
   expect_equal( dim(my_DNAbin)[2], dim(gene)[2] )
@@ -139,7 +160,8 @@ test_that("vcfR2DNAbin works for diploid data, ref.seq is not NULL",{
 
 
 test_that("vcfR2DNAbin works for triploid data, no ref.seq",{
-  my_DNAbin <- vcfR2DNAbin( vcf3, gt.split = "|", verbose = FALSE )
+#  my_DNAbin <- vcfR2DNAbin( vcf3, gt.split = "|", verbose = FALSE )
+  my_DNAbin <- vcfR2DNAbin( vcf3, verbose = FALSE )
   expect_true( inherits(my_DNAbin, "DNAbin") )  
   expect_equal( dim(my_DNAbin)[2], nrow( extract.indels(vcf)@gt ) )
   expect_equal( dim(my_DNAbin)[1], 3 * (ncol(vcf@gt) - 1) )
@@ -157,11 +179,12 @@ test_that("vcfR2DNAbin does not include variants at end.pos + 1",{
 #  vcf@fix[586,1:6]
 #  vcf@fix[586,2] <- "24527"
   vcf@fix[586,2] <- "24528"
-  my_DNAbin <- vcfR2DNAbin( vcf, gt.split = "|", ref.seq = gene, start.pos = gff[1,4], verbose = FALSE )
+#  my_DNAbin <- vcfR2DNAbin( vcf, gt.split = "|", ref.seq = gene, start.pos = gff[1,4], verbose = FALSE )
+  my_DNAbin <- vcfR2DNAbin( vcf, ref.seq = gene, start.pos = gff[1,4], verbose = FALSE )
   expect_true( inherits(my_DNAbin, "DNAbin") )  
   expect_equal(length(ape::seg.sites(my_DNAbin)), 40)
 })
 
 
 ##### ##### ##### ##### #####
-# EOF.
\ No newline at end of file
+# EOF.
