@@ -1,5 +1,6 @@
 #detach(package:vcfR, unload=TRUE)
 library(vcfR)
+library(testthat)
 context("io functions")
 
 # Load data
@@ -60,7 +61,8 @@ test_that("vcfR_read_body_gz works",{
   write.vcf(chrom, "test.vcf.gz")
   stats <- .Call('vcfR_vcf_stats_gz', PACKAGE = 'vcfR', "test.vcf.gz")
   body <- .Call('vcfR_read_body_gz', PACKAGE = 'vcfR', "test.vcf.gz", stats,
-                nrows = -1, skip = 0, cols=1:stats['columns'], 0)
+                nrows = -1, skip = 0, cols=1:stats['columns'],
+                convertNA = 1, verbose  = 0)
   unlink("test.vcf.gz")
   setwd(original_dir)
 
