@@ -1,7 +1,9 @@
 
+
+
+#
+library(testthat)
 context("vcfR methods")
-
-#library(testthat)
 library(vcfR)
 data("vcfR_example")
 
@@ -33,4 +35,4 @@ test_that("nrow works",{
 
 
 ##### ##### ##### ##### #####
-# EOF.
\ No newline at end of file
+# EOF.
